From: Duy Nguyen Date: Tue, 03 Sep 2013 11:49:02 GMT Subject: Re: [PATCH v2] Document pack v4 format Message-ID: In-Reply-To: On Tue, Sep 3, 2013 at 1:46 PM, Nicolas Pitre wrote: > So... looks like pack v4 is now "functional". > > However something is still wrong as it operates about 6 times slower > than pack v3. > > Anyone wishes to investigate? You recurse in decode_entries too deep.I check the first 10000 decode_entries() calls in pv4_get_tree(). The deepest level is 3491. -- Duy